# V1alpha1ItemValue

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bool_val** | **bool** |  | 
**list_val** | **list[str]** |  | 
**map_val** | **dict(str, str)** |  | 
**num_val** | **str** |  | 
**str_val** | **str** |  | 
**type** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


